@@ -1,9 +1,8 @@
 package Pfacter;
 
-our $VERSION = '1.14';
-
 sub modulelist {
-    my $self   = shift;
+    my $self = shift;
+
     my $kernel = shift;
 
     my @modules = qw(
@@ -11,12 +10,9 @@ sub modulelist {
         architecture
         disk
         domain
-        filesystems
         fqdn
-        hardwaremanufacturer
         hardwaremodel
         hardwareplatform
-        hardwareproduct
         hostname
         ipaddress
         kernel
@@ -29,9 +25,7 @@ sub modulelist {
         operatingsystem
         processor
         processorcount
-        productid
         serialnumber
-        swap
         uniqueid
 
     );
@@ -41,6 +35,8 @@ sub modulelist {
         /Linux/ && do {
             push @modules, qw(
 
+                hardwaremanufacturer
+                hardwareproduct
                 lsbdescription
                 lsbid
                 lsbrelease
