@@ -1,28 +1,14 @@
 package Pfacter::hardwareproduct;
 
-#
-
 sub pfact {
     my $self  = shift;
     my ( $p ) = shift->{'pfact'};
 
-    my ( $r );
-
     for ( $p->{'kernel'} ) {
-        /Darwin/ && do {
-            if ( -e '/usr/sbin/system_profiler' ) {
-                open( F, '/usr/sbin/system_profiler SPHardwareDataType |' );
-                my ( @F ) = <F>;
-                close( F );
-
-                foreach ( @F ) {
-                    if ( /Machine Name\:\s+(.+?)$/ ) { $r = $1; last; }
-                }
-            }
-        };
-
         /Linux/ && do {
             if ( -e '/usr/sbin/dmidecode' ) {
+                my ( $f );
+
                 local $/;
                 $/ = /^Handle \d+x/;
 
@@ -31,30 +17,24 @@ sub pfact {
                 close( F );
 
                 # Multi-version dmidecode compat
-                if ( @F == 1 ) { @F = split( /Handle/, $F[0] ); }
+                if ( @F == 1 ) { @F = split /Handle/, $F[0]; }
 
                 foreach ( @F ) {
                     if ( /type 1,/ ) {
                         if ( /Product Name:\s+(.*)\s+/ ) {
-                            $r = $1;
+                            my $p = $1;
 
-                            $r =~ s/\s+/ /g;
-                            $r =~ s/\s+$//g;
+                            $p =~ s/\s+/ /g;
+                            $p =~ s/\s+$//g;
+
+                            return $p;
                         }
                     }
                 }
             }
         };
 
-        /SunOS/ && do {
-            if ( -e '/usr/bin/uname' ) {
-                $r = qx( /bin/uname -i );
-                $r = $1 if /^.+?,(.*)$/;
-            }
-        };
-
-        if ( $r ) { return( $r ); }
-        else      { return( 0 ); }
+        return qq((kernel not supported));
     }
 }
 
